-file("/usr/lib64/erlang/lib/parsetools-2.3/include/leexinc.hrl", 0).
%% The source of this file is part of leex distribution, as such it
%% has the same Copyright as the other files in the leex
%% distribution. The Copyright is defined in the accompanying file
%% COPYRIGHT. However, the resultant scanner generated by leex is the
%% property of the creator of the scanner and is not covered by that
%% Copyright.

-module(tomerl_lexer).

-export([string/1, string/2, token/2, token/3, tokens/2, tokens/3]).
-export([format_error/1]).

%% User code. This is placed here to allow extra attributes.
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 111).

-ignore_xref([
    format_error/1,
    string/1,
    string/2,
    token/2,
    token/3,
    tokens/2,
    tokens/3
]).
-export([tokenize/1]).

%% @doc Lexer entry point.

-spec tokenize(string() | binary() | iolist()) ->
    {ok, [term()], integer()} | {error, term(), integer()}.

tokenize(String) ->
    string(unicode:characters_to_list([String, $\n])).

%%----------------------------------------------------------

to_integer("+" ++ String) ->
    to_integer(String);
to_integer("-" ++ String) ->
    -to_integer(String);
to_integer("0b" ++ String) ->
    to_integer(String, 2);
to_integer("0o" ++ String) ->
    to_integer(String, 8);
to_integer("0x" ++ String) ->
    to_integer(String, 16);
to_integer(String) ->
    to_integer(String, 10).

to_integer(String, Base) ->
    list_to_integer([C || C <- String, C /= $_], Base).

to_float(String) ->
    StripUnderscore = [C || C <- String, C /= $_],
    case string:chr(StripUnderscore, $.) of
        0 ->
            % fix the float for Erlang's parsing function by inserting the missing
            % fraction part just before "e" marker
            % NOTE: we're here because either "." or "[eE]" was found in the number,
            % and we know the "." is missing
            [A, B] = string:tokens(StripUnderscore, "eE"),
            list_to_float(A ++ ".0e" ++ B);
        _ ->
            list_to_float(StripUnderscore)
    end.

datetime_tz(String) ->
    StrLen = length(String),
    case lists:last(String) of
        $Z ->
            tomerl_datetime:with_offset(
                local_datetime(string:substr(String, 1, StrLen - 1)),
                z
            );
        _ ->
            Timezone = string:substr(String, 1 + StrLen - 6, 6),
            [HH, MM] = string:tokens(Timezone, ":"),
            OffsetHours = list_to_integer(HH),
            OffsetMinutes = list_to_integer(MM),
            Offset = abs(OffsetHours) * 60 + OffsetMinutes,
            Offset1 =
                if
                    OffsetHours < 0 -> -Offset;
                    true -> Offset
                end,
            tomerl_datetime:with_offset(
                local_datetime(string:substr(String, 1, StrLen - 6)),
                Offset1
            )
    end.

local_datetime(String) ->
    [Date, Time] = string:tokens(String, "T "),
    tomerl_datetime:new_datetime(local_date(Date), local_time(Time)).

local_date(String) ->
    [Y, M, D] = string:tokens(String, "-"),
    tomerl_datetime:new_date(
        list_to_integer(Y),
        list_to_integer(M),
        list_to_integer(D)
    ).

local_time(String) ->
    [HH, MM, SS] = string:tokens(String, ":"),
    case string:tokens(SS, ".") of
        [_] ->
            tomerl_datetime:new_time(
                list_to_integer(HH),
                list_to_integer(MM),
                list_to_integer(SS)
            );
        [S, Frac] ->
            tomerl_datetime:new_time(
                list_to_integer(HH),
                list_to_integer(MM),
                list_to_integer(S),
                list_to_integer(Frac)
            )
    end.

literal_string(String) ->
    string:substr(String, 2, length(String) - 2).

literal_string_ml(String) ->
    case string:substr(String, 4, length(String) - 6) of
        "\r\n" ++ Result -> Result;
        "\n" ++ Result -> Result;
        Result -> Result
    end.

basic_string(String) ->
    esc_codes(string:substr(String, 2, length(String) - 2)).

basic_string_ml(String) ->
    case string:substr(String, 4, length(String) - 6) of
        "\r\n" ++ Result -> esc_codes(Result);
        "\n" ++ Result -> esc_codes(Result);
        Result -> esc_codes(Result)
    end.

esc_codes("") ->
    "";
esc_codes("\\b" ++ Rest) ->
    [$\b | esc_codes(Rest)];
esc_codes("\\t" ++ Rest) ->
    [$\t | esc_codes(Rest)];
esc_codes("\\n" ++ Rest) ->
    [$\n | esc_codes(Rest)];
esc_codes("\\f" ++ Rest) ->
    [$\f | esc_codes(Rest)];
esc_codes("\\r" ++ Rest) ->
    [$\r | esc_codes(Rest)];
esc_codes("\\\"" ++ Rest) ->
    [$\" | esc_codes(Rest)];
esc_codes("\\\\" ++ Rest) ->
    [$\\ | esc_codes(Rest)];
esc_codes("\\u" ++ [C1, C2, C3, C4 | Rest]) ->
    [u([C4, C3, C2, C1]) | esc_codes(Rest)];
esc_codes("\\U" ++ [C1, C2, C3, C4, C5, C6, C7, C8 | Rest]) ->
    [u([C8, C7, C6, C5, C4, C3, C2, C1]) | esc_codes(Rest)];
esc_codes("\\" ++ Rest) ->
    % XXX: "dangling" backslash can only occur in multiline basic strings
    % (regexps are designed so), so this clause will never be called for basic
    % string
    esc_codes(skip_spaces(Rest));
esc_codes([C | Rest]) ->
    [C | esc_codes(Rest)].

skip_spaces(" " ++ Rest) -> skip_spaces(Rest);
skip_spaces("\t" ++ Rest) -> skip_spaces(Rest);
skip_spaces("\n" ++ Rest) -> skip_spaces(Rest);
skip_spaces("\r\n" ++ Rest) -> skip_spaces(Rest);
skip_spaces(String) -> String.

u([]) -> 0;
u([C | Rest]) when C >= $0 andalso C =< $9 -> (C - $0) + 16 * u(Rest);
u([C | Rest]) when C >= $A andalso C =< $F -> (10 + C - $A) + 16 * u(Rest);
u([C | Rest]) when C >= $a andalso C =< $f -> (10 + C - $a) + 16 * u(Rest).

%%%---------------------------------------------------------------------------
%%% vim:ft=erlang

-file("/usr/lib64/erlang/lib/parsetools-2.3/include/leexinc.hrl", 14).

format_error({illegal, S}) -> ["illegal characters ", io_lib:write_string(S)];
format_error({user, S}) -> S.

string(String) -> string(String, 1).

string(String, Line) -> string(String, Line, String, []).

%% string(InChars, Line, TokenChars, Tokens) ->
%% {ok,Tokens,Line} | {error,ErrorInfo,Line}.
%% Note the line number going into yystate, L0, is line of token
%% start while line number returned is line of token end. We want line
%% of token start.

% No partial tokens!
string([], L, [], Ts) ->
    {ok, yyrev(Ts), L};
string(Ics0, L0, Tcs, Ts) ->
    case yystate(yystate(), Ics0, L0, 0, reject, 0) of
        % Accepting end state
        {A, Alen, Ics1, L1} ->
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        % Accepting transistion state
        {A, Alen, Ics1, L1, _S1} ->
            string_cont(Ics1, L1, yyaction(A, Alen, Tcs, L0), Ts);
        % After a non-accepting state
        {reject, _Alen, Tlen, _Ics1, L1, _S1} ->
            {error, {L0, ?MODULE, {illegal, yypre(Tcs, Tlen + 1)}}, L1};
        {A, Alen, Tlen, _Ics1, L1, _S1} ->
            Tcs1 = yysuf(Tcs, Alen),
            L2 = adjust_line(Tlen, Alen, Tcs1, L1),
            string_cont(Tcs1, L2, yyaction(A, Alen, Tcs, L0), Ts)
    end.

%% string_cont(RestChars, Line, Token, Tokens)
%% Test for and remove the end token wrapper. Push back characters
%% are prepended to RestChars.

-dialyzer({nowarn_function, string_cont/4}).

string_cont(Rest, Line, {token, T}, Ts) ->
    string(Rest, Line, Rest, [T | Ts]);
string_cont(Rest, Line, {token, T, Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T | Ts]);
string_cont(Rest, Line, {end_token, T}, Ts) ->
    string(Rest, Line, Rest, [T | Ts]);
string_cont(Rest, Line, {end_token, T, Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, [T | Ts]);
string_cont(Rest, Line, skip_token, Ts) ->
    string(Rest, Line, Rest, Ts);
string_cont(Rest, Line, {skip_token, Push}, Ts) ->
    NewRest = Push ++ Rest,
    string(NewRest, Line, NewRest, Ts);
string_cont(_Rest, Line, {error, S}, _Ts) ->
    {error, {Line, ?MODULE, {user, S}}, Line}.

%% token(Continuation, Chars) ->
%% token(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {token,State,CurrLine,TokenChars,TokenLen,TokenLine,AccAction,AccLen}

token(Cont, Chars) -> token(Cont, Chars, 1).

token([], Chars, Line) ->
    token(yystate(), Chars, Line, Chars, 0, Line, reject, 0);
token({token, State, Line, Tcs, Tlen, Tline, Action, Alen}, Chars, _) ->
    token(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Action, Alen).

%% token(State, InChars, Line, TokenChars, TokenLen, TokenLine,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% The argument order is chosen to be more efficient.

token(S0, Ics0, L0, Tcs, Tlen0, Tline, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1, Alen1, Ics1, L1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% Accepting transition state, can take more chars.

        % Need more chars to check
        {A1, Alen1, [], L1, S1} ->
            {more, {token, S1, L1, Tcs, Alen1, Tline, A1, Alen1}};
        % Take what we got
        {A1, Alen1, Ics1, L1, _S1} ->
            token_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline));
        %% After a non-accepting state, maybe reach accept state later.

        % Need more chars to check
        {A1, Alen1, Tlen1, [], L1, S1} ->
            {more, {token, S1, L1, Tcs, Tlen1, Tline, A1, Alen1}};
        % No token match
        {reject, _Alen1, Tlen1, eof, L1, _S1} ->
            %% Check for partial token which is error.
            Ret =
                if
                    Tlen1 > 0 ->
                        {error,
                            {Tline, ?MODULE,
                                %% Skip eof tail in Tcs.
                                {illegal, yypre(Tcs, Tlen1)}},
                            L1};
                    true ->
                        {eof, L1}
                end,
            {done, Ret, eof};
        % No token match
        {reject, _Alen1, Tlen1, Ics1, L1, _S1} ->
            Error = {Tline, ?MODULE, {illegal, yypre(Tcs, Tlen1 + 1)}},
            {done, {error, Error, L1}, Ics1};
        % Use last accept match
        {A1, Alen1, Tlen1, _Ics1, L1, _S1} ->
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            token_cont(Tcs1, L2, yyaction(A1, Alen1, Tcs, Tline))
    end.

%% token_cont(RestChars, Line, Token)
%% If we have a token or error then return done, else if we have a
%% skip_token then continue.

-dialyzer({nowarn_function, token_cont/3}).

token_cont(Rest, Line, {token, T}) ->
    {done, {ok, T, Line}, Rest};
token_cont(Rest, Line, {token, T, Push}) ->
    NewRest = Push ++ Rest,
    {done, {ok, T, Line}, NewRest};
token_cont(Rest, Line, {end_token, T}) ->
    {done, {ok, T, Line}, Rest};
token_cont(Rest, Line, {end_token, T, Push}) ->
    NewRest = Push ++ Rest,
    {done, {ok, T, Line}, NewRest};
token_cont(Rest, Line, skip_token) ->
    token(yystate(), Rest, Line, Rest, 0, Line, reject, 0);
token_cont(Rest, Line, {skip_token, Push}) ->
    NewRest = Push ++ Rest,
    token(yystate(), NewRest, Line, NewRest, 0, Line, reject, 0);
token_cont(Rest, Line, {error, S}) ->
    {done, {error, {Line, ?MODULE, {user, S}}, Line}, Rest}.

%% tokens(Continuation, Chars, Line) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.
%% Must be careful when re-entering to append the latest characters to the
%% after characters in an accept. The continuation is:
%% {tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Tokens,AccAction,AccLen}
%% {skip_tokens,State,CurrLine,TokenChars,TokenLen,TokenLine,Error,AccAction,AccLen}

tokens(Cont, Chars) -> tokens(Cont, Chars, 1).

tokens([], Chars, Line) ->
    tokens(yystate(), Chars, Line, Chars, 0, Line, [], reject, 0);
tokens({tokens, State, Line, Tcs, Tlen, Tline, Ts, Action, Alen}, Chars, _) ->
    tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Ts, Action, Alen);
tokens({skip_tokens, State, Line, Tcs, Tlen, Tline, Error, Action, Alen}, Chars, _) ->
    skip_tokens(State, Chars, Line, Tcs ++ Chars, Tlen, Tline, Error, Action, Alen).

%% tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Ts, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        %% Accepting end state, we have a token.
        {A1, Alen1, Ics1, L1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% Accepting transition state, can take more chars.

        % Need more chars to check
        {A1, Alen1, [], L1, S1} ->
            {more, {tokens, S1, L1, Tcs, Alen1, Tline, Ts, A1, Alen1}};
        % Take what we got
        {A1, Alen1, Ics1, L1, _S1} ->
            tokens_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Ts);
        %% After a non-accepting state, maybe reach accept state later.

        % Need more chars to check
        {A1, Alen1, Tlen1, [], L1, S1} ->
            {more, {tokens, S1, L1, Tcs, Tlen1, Tline, Ts, A1, Alen1}};
        % No token match
        {reject, _Alen1, Tlen1, eof, L1, _S1} ->
            %% Check for partial token which is error, no need to skip here.
            Ret =
                if
                    Tlen1 > 0 ->
                        {error,
                            {Tline, ?MODULE,
                                %% Skip eof tail in Tcs.
                                {illegal, yypre(Tcs, Tlen1)}},
                            L1};
                    Ts == [] ->
                        {eof, L1};
                    true ->
                        {ok, yyrev(Ts), L1}
                end,
            {done, Ret, eof};
        {reject, _Alen1, Tlen1, _Ics1, L1, _S1} ->
            %% Skip rest of tokens.
            Error = {L1, ?MODULE, {illegal, yypre(Tcs, Tlen1 + 1)}},
            skip_tokens(yysuf(Tcs, Tlen1 + 1), L1, Error);
        {A1, Alen1, Tlen1, _Ics1, L1, _S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            tokens_cont(Tcs1, L2, Token, Ts)
    end.

%% tokens_cont(RestChars, Line, Token, Tokens)
%% If we have an end_token or error then return done, else if we have
%% a token then save it and continue, else if we have a skip_token
%% just continue.

-dialyzer({nowarn_function, tokens_cont/4}).

tokens_cont(Rest, Line, {token, T}, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, [T | Ts], reject, 0);
tokens_cont(Rest, Line, {token, T, Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, [T | Ts], reject, 0);
tokens_cont(Rest, Line, {end_token, T}, Ts) ->
    {done, {ok, yyrev(Ts, [T]), Line}, Rest};
tokens_cont(Rest, Line, {end_token, T, Push}, Ts) ->
    NewRest = Push ++ Rest,
    {done, {ok, yyrev(Ts, [T]), Line}, NewRest};
tokens_cont(Rest, Line, skip_token, Ts) ->
    tokens(yystate(), Rest, Line, Rest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {skip_token, Push}, Ts) ->
    NewRest = Push ++ Rest,
    tokens(yystate(), NewRest, Line, NewRest, 0, Line, Ts, reject, 0);
tokens_cont(Rest, Line, {error, S}, _Ts) ->
    skip_tokens(Rest, Line, {Line, ?MODULE, {user, S}}).

%%skip_tokens(InChars, Line, Error) -> {done,{error,Error,Line},Ics}.
%% Skip tokens until an end token, junk everything and return the error.

skip_tokens(Ics, Line, Error) ->
    skip_tokens(yystate(), Ics, Line, Ics, 0, Line, Error, reject, 0).

%% skip_tokens(State, InChars, Line, TokenChars, TokenLen, TokenLine, Tokens,
%% AcceptAction, AcceptLen) ->
%% {more,Continuation} | {done,ReturnVal,RestChars}.

skip_tokens(S0, Ics0, L0, Tcs, Tlen0, Tline, Error, A0, Alen0) ->
    case yystate(S0, Ics0, L0, Tlen0, A0, Alen0) of
        % Accepting end state
        {A1, Alen1, Ics1, L1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        % After an accepting state
        {A1, Alen1, [], L1, S1} ->
            {more, {skip_tokens, S1, L1, Tcs, Alen1, Tline, Error, A1, Alen1}};
        {A1, Alen1, Ics1, L1, _S1} ->
            skip_cont(Ics1, L1, yyaction(A1, Alen1, Tcs, Tline), Error);
        % After a non-accepting state
        {A1, Alen1, Tlen1, [], L1, S1} ->
            {more, {skip_tokens, S1, L1, Tcs, Tlen1, Tline, Error, A1, Alen1}};
        {reject, _Alen1, _Tlen1, eof, L1, _S1} ->
            {done, {error, Error, L1}, eof};
        {reject, _Alen1, Tlen1, _Ics1, L1, _S1} ->
            skip_tokens(yysuf(Tcs, Tlen1 + 1), L1, Error);
        {A1, Alen1, Tlen1, _Ics1, L1, _S1} ->
            Token = yyaction(A1, Alen1, Tcs, Tline),
            Tcs1 = yysuf(Tcs, Alen1),
            L2 = adjust_line(Tlen1, Alen1, Tcs1, L1),
            skip_cont(Tcs1, L2, Token, Error)
    end.

%% skip_cont(RestChars, Line, Token, Error)
%% Skip tokens until we have an end_token or error then return done
%% with the original rror.

-dialyzer({nowarn_function, skip_cont/4}).

skip_cont(Rest, Line, {token, _T}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {token, _T, Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {end_token, _T}, Error) ->
    {done, {error, Error, Line}, Rest};
skip_cont(Rest, Line, {end_token, _T, Push}, Error) ->
    NewRest = Push ++ Rest,
    {done, {error, Error, Line}, NewRest};
skip_cont(Rest, Line, skip_token, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {skip_token, Push}, Error) ->
    NewRest = Push ++ Rest,
    skip_tokens(yystate(), NewRest, Line, NewRest, 0, Line, Error, reject, 0);
skip_cont(Rest, Line, {error, _S}, Error) ->
    skip_tokens(yystate(), Rest, Line, Rest, 0, Line, Error, reject, 0).

-compile({nowarn_unused_function, [yyrev/1, yyrev/2, yypre/2, yysuf/2]}).

yyrev(List) -> lists:reverse(List).
yyrev(List, Tail) -> lists:reverse(List, Tail).
yypre(List, N) -> lists:sublist(List, N).
yysuf(List, N) -> lists:nthtail(N, List).

%% adjust_line(TokenLength, AcceptLength, Chars, Line) -> NewLine
%% Make sure that newlines in Chars are not counted twice.
%% Line has been updated with respect to newlines in the prefix of
%% Chars consisting of (TokenLength - AcceptLength) characters.

-compile({nowarn_unused_function, adjust_line/4}).

adjust_line(N, N, _Cs, L) -> L;
adjust_line(T, A, [$\n | Cs], L) -> adjust_line(T - 1, A, Cs, L - 1);
adjust_line(T, A, [_ | Cs], L) -> adjust_line(T - 1, A, Cs, L).

%% yystate() -> InitialState.
%% yystate(State, InChars, Line, CurrTokLen, AcceptAction, AcceptLen) ->
%% {Action, AcceptLen, RestChars, Line} |
%% {Action, AcceptLen, RestChars, Line, State} |
%% {reject, AcceptLen, CurrTokLen, RestChars, Line, State} |
%% {Action, AcceptLen, CurrTokLen, RestChars, Line, State}.
%% Generated state transition functions. The non-accepting end state
%% return signal either an unrecognised character or end of current
%% input.

-file("/home/benedikt/git/tomerl/src/tomerl_lexer.erl", 464).
yystate() -> 105.

yystate(168, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(84, Ics, Line, Tlen + 1, Action, Alen);
yystate(168, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 168};
yystate(167, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(123, Ics, Line, Tlen + 1, Action, Alen);
yystate(167, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(116, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(167, [C | Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 38 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(167, [C | Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 126 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(167, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(167, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 167};
yystate(166, [46 | Ics], Line, Tlen, _, _) ->
    yystate(102, Ics, Line, Tlen + 1, 13, Tlen);
yystate(166, Ics, Line, Tlen, _, _) ->
    {13, Tlen, Ics, Line, 166};
yystate(165, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(109, Ics, Line, Tlen + 1, Action, Alen);
yystate(165, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(109, Ics, Line, Tlen + 1, Action, Alen);
yystate(165, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(109, Ics, Line, Tlen + 1, Action, Alen);
yystate(165, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 165};
yystate(164, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(100, Ics, Line, Tlen + 1, Action, Alen);
yystate(164, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(100, Ics, Line, Tlen + 1, Action, Alen);
yystate(164, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(100, Ics, Line, Tlen + 1, Action, Alen);
yystate(164, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 164};
yystate(163, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [58 | Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(163, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 163};
yystate(162, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(112, Ics, Line, Tlen + 1, Action, Alen);
yystate(162, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 162};
yystate(161, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(113, Ics, Line, Tlen + 1, Action, Alen);
yystate(161, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(113, Ics, Line, Tlen + 1, Action, Alen);
yystate(161, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(113, Ics, Line, Tlen + 1, Action, Alen);
yystate(161, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 161};
yystate(160, [102 | Ics], Line, Tlen, _, _) ->
    yystate(114, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, [C | Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(160, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 160};
yystate(159, [110 | Ics], Line, Tlen, _, _) ->
    yystate(95, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, [C | Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(159, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 159};
yystate(158, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(94, Ics, Line, Tlen + 1, Action, Alen);
yystate(158, [C | Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 38 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(158, [C | Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 126 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(158, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(158, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 158};
yystate(157, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(117, Ics, Line, Tlen + 1, Action, Alen);
yystate(157, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 157};
yystate(156, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(97, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(46, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [33 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [C | Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [C | Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 126 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(156, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 156};
yystate(155, Ics, Line, Tlen, _, _) ->
    {20, Tlen, Ics, Line};
yystate(154, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(154, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(154, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(122, Ics, Line, Tlen + 1, 29, Tlen);
yystate(154, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(154, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(154, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 154};
yystate(153, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(89, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(89, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [C | Ics], Line, Tlen, _, _) when C >= 71, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(89, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, [C | Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(153, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 153};
yystate(152, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(2, Ics, Line, Tlen + 1, Action, Alen);
yystate(152, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(2, Ics, Line, Tlen + 1, Action, Alen);
yystate(152, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(2, Ics, Line, Tlen + 1, Action, Alen);
yystate(152, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 152};
yystate(151, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(151, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(151, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(151, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 151};
yystate(150, [117 | Ics], Line, Tlen, _, _) ->
    yystate(124, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 116 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, [C | Ics], Line, Tlen, _, _) when C >= 118, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(150, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 150};
yystate(149, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(85, Ics, Line, Tlen + 1, Action, Alen);
yystate(149, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 149};
yystate(148, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(84, Ics, Line, Tlen + 1, Action, Alen);
yystate(148, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 148};
yystate(147, [117 | Ics], Line, Tlen, Action, Alen) ->
    yystate(165, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [116 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [114 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [102 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [98 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [85 | Ics], Line, Tlen, Action, Alen) ->
    yystate(90, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(83, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(147, [9 | Ics], Line, Tlen, Action, Alen) ->
    yystate(83, Ics, Line, Tlen + 1, Action, Alen);
yystate(147, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 147};
yystate(146, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(82, Ics, Line, Tlen + 1, Action, Alen);
yystate(146, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 146};
yystate(145, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 51 ->
    yystate(129, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, [C | Ics], Line, Tlen, _, _) when C >= 52, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(145, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 145};
yystate(144, [115 | Ics], Line, Tlen, _, _) ->
    yystate(130, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 114 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, [C | Ics], Line, Tlen, _, _) when C >= 116, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(144, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 144};
yystate(143, [110 | Ics], Line, Tlen, _, _) ->
    yystate(79, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [105 | Ics], Line, Tlen, _, _) ->
    yystate(96, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [48 | Ics], Line, Tlen, _, _) ->
    yystate(50, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [C | Ics], Line, Tlen, _, _) when C >= 49, C =< 57 ->
    yystate(5, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 104 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [C | Ics], Line, Tlen, _, _) when C >= 106, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, [C | Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(143, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 143};
yystate(142, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(142, [45 | Ics], Line, Tlen, _, _) ->
    yystate(78, Ics, Line, Tlen + 1, 29, Tlen);
yystate(142, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(142, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(142, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(142, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 142};
yystate(141, Ics, Line, Tlen, _, _) ->
    {7, Tlen, Ics, Line};
yystate(140, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(166, Ics, Line, Tlen + 1, Action, Alen);
yystate(140, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 140};
yystate(139, [50 | Ics], Line, Tlen, Action, Alen) ->
    yystate(135, Ics, Line, Tlen + 1, Action, Alen);
yystate(139, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(104, Ics, Line, Tlen + 1, Action, Alen);
yystate(139, [49 | Ics], Line, Tlen, Action, Alen) ->
    yystate(104, Ics, Line, Tlen + 1, Action, Alen);
yystate(139, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 139};
yystate(138, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(80, Ics, Line, Tlen + 1, Action, Alen);
yystate(138, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 138};
yystate(137, Ics, Line, Tlen, _, _) ->
    {0, Tlen, Ics, Line};
yystate(136, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(155, Ics, Line, Tlen + 1, Action, Alen);
yystate(136, [45 | Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen + 1, Action, Alen);
yystate(136, [43 | Ics], Line, Tlen, Action, Alen) ->
    yystate(4, Ics, Line, Tlen + 1, Action, Alen);
yystate(136, [C | Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(55, Ics, Line, Tlen + 1, Action, Alen);
yystate(136, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 136};
yystate(135, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 51 ->
    yystate(71, Ics, Line, Tlen + 1, Action, Alen);
yystate(135, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 135};
yystate(134, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [48 | Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [49 | Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [C | Ics], Line, Tlen, _, _) when C >= 50, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(134, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 134};
yystate(133, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(107, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(133, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 133};
yystate(132, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 50 ->
    yystate(142, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, [C | Ics], Line, Tlen, _, _) when C >= 51, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(132, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 132};
yystate(131, Ics, Line, Tlen, _, _) ->
    {6, Tlen, Ics, Line};
yystate(130, [101 | Ics], Line, Tlen, _, _) ->
    yystate(66, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(130, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 130};
yystate(129, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, [58 | Ics], Line, Tlen, _, _) ->
    yystate(65, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(129, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 129};
yystate(128, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(155, Ics, Line, Tlen + 1, Action, Alen);
yystate(128, [45 | Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen + 1, Action, Alen);
yystate(128, [43 | Ics], Line, Tlen, Action, Alen) ->
    yystate(47, Ics, Line, Tlen + 1, Action, Alen);
yystate(128, [C | Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(72, Ics, Line, Tlen + 1, Action, Alen);
yystate(128, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 128};
yystate(127, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(147, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(27, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [33 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(127, [C | Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [C | Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 126 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(127, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 127};
yystate(126, [54 | Ics], Line, Tlen, Action, Alen) ->
    yystate(148, Ics, Line, Tlen + 1, Action, Alen);
yystate(126, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 53 ->
    yystate(168, Ics, Line, Tlen + 1, Action, Alen);
yystate(126, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 126};
yystate(125, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(125, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(125, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(17, Ics, Line, Tlen + 1, 29, Tlen);
yystate(125, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(125, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(125, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 125};
yystate(124, [101 | Ics], Line, Tlen, _, _) ->
    yystate(60, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(124, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 124};
yystate(123, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(67, Ics, Line, Tlen + 1, Action, Alen);
yystate(123, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(116, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(123, [C | Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 38 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(123, [C | Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 126 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(123, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(123, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 123};
yystate(122, [95 | Ics], Line, Tlen, _, _) ->
    yystate(154, Ics, Line, Tlen + 1, 18, Tlen);
yystate(122, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(122, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(122, Ics, Line, Tlen + 1, 18, Tlen);
yystate(122, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(122, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(122, Ics, Line, Tlen, _, _) ->
    {18, Tlen, Ics, Line, 122};
yystate(121, [121 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [122 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [120 | Ics], Line, Tlen, _, _) ->
    yystate(153, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [111 | Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [99 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [100 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [98 | Ics], Line, Tlen, _, _) ->
    yystate(134, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [97 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(44, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 110 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, [C | Ics], Line, Tlen, _, _) when C >= 112, C =< 119 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(121, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 121};
yystate(120, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(120, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(120, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(120, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(120, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 18, Tlen);
yystate(120, Ics, Line, Tlen, _, _) ->
    {18, Tlen, Ics, Line, 120};
yystate(119, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(55, Ics, Line, Tlen + 1, Action, Alen);
yystate(119, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 119};
yystate(118, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(118, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 118};
yystate(117, Ics, Line, Tlen, _, _) ->
    {25, Tlen, Ics, Line};
yystate(116, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(167, Ics, Line, Tlen + 1, Action, Alen);
yystate(116, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(116, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(116, [C | Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 38 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(116, [C | Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 126 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(116, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(116, Ics, Line, Tlen + 1, Action, Alen);
yystate(116, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 116};
yystate(115, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 16, Tlen);
yystate(115, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 16, Tlen);
yystate(115, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 16, Tlen);
yystate(115, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 16, Tlen);
yystate(115, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 16, Tlen);
yystate(115, Ics, Line, Tlen, _, _) ->
    {16, Tlen, Ics, Line, 115};
yystate(114, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 28, Tlen);
yystate(114, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 28, Tlen);
yystate(114, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 28, Tlen);
yystate(114, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 28, Tlen);
yystate(114, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 28, Tlen);
yystate(114, Ics, Line, Tlen, _, _) ->
    {28, Tlen, Ics, Line, 114};
yystate(113, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(49, Ics, Line, Tlen + 1, Action, Alen);
yystate(113, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(49, Ics, Line, Tlen + 1, Action, Alen);
yystate(113, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(49, Ics, Line, Tlen + 1, Action, Alen);
yystate(113, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 113};
yystate(112, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen + 1, Action, Alen);
yystate(112, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 112};
yystate(111, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 51 ->
    yystate(163, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 52, C =< 57 ->
    yystate(107, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(111, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 111};
yystate(110, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(164, Ics, Line, Tlen + 1, Action, Alen);
yystate(110, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(164, Ics, Line, Tlen + 1, Action, Alen);
yystate(110, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(164, Ics, Line, Tlen + 1, Action, Alen);
yystate(110, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 110};
yystate(109, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(152, Ics, Line, Tlen + 1, Action, Alen);
yystate(109, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(152, Ics, Line, Tlen + 1, Action, Alen);
yystate(109, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(152, Ics, Line, Tlen + 1, Action, Alen);
yystate(109, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 109};
yystate(108, [95 | Ics], Line, Tlen, _, _) ->
    yystate(134, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [48 | Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [49 | Ics], Line, Tlen, _, _) ->
    yystate(108, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [C | Ics], Line, Tlen, _, _) when C >= 50, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 23, Tlen);
yystate(108, Ics, Line, Tlen, _, _) ->
    {23, Tlen, Ics, Line, 108};
yystate(107, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(51, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(107, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 107};
yystate(106, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(106, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(106, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(129, Ics, Line, Tlen + 1, 29, Tlen);
yystate(106, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(106, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(106, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 106};
yystate(105, [125 | Ics], Line, Tlen, Action, Alen) ->
    yystate(41, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [123 | Ics], Line, Tlen, Action, Alen) ->
    yystate(22, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [116 | Ics], Line, Tlen, Action, Alen) ->
    yystate(86, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(0, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [105 | Ics], Line, Tlen, Action, Alen) ->
    yystate(159, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [103 | Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [104 | Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [102 | Ics], Line, Tlen, Action, Alen) ->
    yystate(28, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [95 | Ics], Line, Tlen, Action, Alen) ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [93 | Ics], Line, Tlen, Action, Alen) ->
    yystate(34, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [91 | Ics], Line, Tlen, Action, Alen) ->
    yystate(29, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [61 | Ics], Line, Tlen, Action, Alen) ->
    yystate(141, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [50 | Ics], Line, Tlen, Action, Alen) ->
    yystate(111, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [49 | Ics], Line, Tlen, Action, Alen) ->
    yystate(57, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(121, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [46 | Ics], Line, Tlen, Action, Alen) ->
    yystate(131, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [45 | Ics], Line, Tlen, Action, Alen) ->
    yystate(143, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [44 | Ics], Line, Tlen, Action, Alen) ->
    yystate(18, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [43 | Ics], Line, Tlen, Action, Alen) ->
    yystate(45, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(39, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [35 | Ics], Line, Tlen, Action, Alen) ->
    yystate(30, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(33, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(9, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(118, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(54, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(105, [9 | Ics], Line, Tlen, Action, Alen) ->
    yystate(9, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 51, C =< 57 ->
    yystate(133, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 101 ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 106, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 111, C =< 115 ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, [C | Ics], Line, Tlen, Action, Alen) when C >= 117, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, Action, Alen);
yystate(105, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 105};
yystate(104, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(71, Ics, Line, Tlen + 1, Action, Alen);
yystate(104, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 104};
yystate(103, [39 | Ics], Line, Tlen, _, _) ->
    yystate(116, Ics, Line, Tlen + 1, 31, Tlen);
yystate(103, Ics, Line, Tlen, _, _) ->
    {31, Tlen, Ics, Line, 103};
yystate(102, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(38, Ics, Line, Tlen + 1, Action, Alen);
yystate(102, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 102};
yystate(101, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(165, Ics, Line, Tlen + 1, Action, Alen);
yystate(101, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(165, Ics, Line, Tlen + 1, Action, Alen);
yystate(101, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(165, Ics, Line, Tlen + 1, Action, Alen);
yystate(101, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 101};
yystate(100, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(36, Ics, Line, Tlen + 1, Action, Alen);
yystate(100, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(36, Ics, Line, Tlen + 1, Action, Alen);
yystate(100, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(36, Ics, Line, Tlen + 1, Action, Alen);
yystate(100, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 100};
yystate(99, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 53 ->
    yystate(43, Ics, Line, Tlen + 1, Action, Alen);
yystate(99, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 99};
yystate(98, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(162, Ics, Line, Tlen + 1, Action, Alen);
yystate(98, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen + 1, Action, Alen);
yystate(98, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(98, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(98, [9 | Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen + 1, Action, Alen);
yystate(98, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 98};
yystate(97, [117 | Ics], Line, Tlen, Action, Alen) ->
    yystate(161, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [116 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [114 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [102 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [98 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [85 | Ics], Line, Tlen, Action, Alen) ->
    yystate(110, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(97, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 97};
yystate(96, [110 | Ics], Line, Tlen, _, _) ->
    yystate(160, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, [C | Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(96, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 96};
yystate(95, [102 | Ics], Line, Tlen, _, _) ->
    yystate(31, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 101 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, [C | Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(95, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 95};
yystate(94, Ics, Line, Tlen, _, _) ->
    {31, Tlen, Ics, Line};
yystate(93, [97 | Ics], Line, Tlen, Action, Alen) ->
    yystate(157, Ics, Line, Tlen + 1, Action, Alen);
yystate(93, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 93};
yystate(92, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(23, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(127, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [33 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(92, [C | Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [C | Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 126 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(92, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 92};
yystate(91, [90 | Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen + 1, 11, Tlen);
yystate(91, [45 | Ics], Line, Tlen, _, _) ->
    yystate(139, Ics, Line, Tlen + 1, 11, Tlen);
yystate(91, [43 | Ics], Line, Tlen, _, _) ->
    yystate(139, Ics, Line, Tlen + 1, 11, Tlen);
yystate(91, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(91, Ics, Line, Tlen + 1, 11, Tlen);
yystate(91, Ics, Line, Tlen, _, _) ->
    {11, Tlen, Ics, Line, 91};
yystate(90, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(26, Ics, Line, Tlen + 1, Action, Alen);
yystate(90, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(26, Ics, Line, Tlen + 1, Action, Alen);
yystate(90, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(26, Ics, Line, Tlen + 1, Action, Alen);
yystate(90, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 90};
yystate(89, [95 | Ics], Line, Tlen, _, _) ->
    yystate(153, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(89, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 70 ->
    yystate(89, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [C | Ics], Line, Tlen, _, _) when C >= 71, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 102 ->
    yystate(89, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, [C | Ics], Line, Tlen, _, _) when C >= 103, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 22, Tlen);
yystate(89, Ics, Line, Tlen, _, _) ->
    {22, Tlen, Ics, Line, 89};
yystate(88, [108 | Ics], Line, Tlen, _, _) ->
    yystate(144, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 107 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, [C | Ics], Line, Tlen, _, _) when C >= 109, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(88, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 88};
yystate(87, [34 | Ics], Line, Tlen, _, _) ->
    yystate(92, Ics, Line, Tlen + 1, 30, Tlen);
yystate(87, Ics, Line, Tlen, _, _) ->
    {30, Tlen, Ics, Line, 87};
yystate(86, [114 | Ics], Line, Tlen, _, _) ->
    yystate(150, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 113 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, [C | Ics], Line, Tlen, _, _) when C >= 115, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(86, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 86};
yystate(85, [58 | Ics], Line, Tlen, Action, Alen) ->
    yystate(65, Ics, Line, Tlen + 1, Action, Alen);
yystate(85, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 85};
yystate(84, [90 | Ics], Line, Tlen, _, _) ->
    yystate(24, Ics, Line, Tlen + 1, 11, Tlen);
yystate(84, [46 | Ics], Line, Tlen, _, _) ->
    yystate(35, Ics, Line, Tlen + 1, 11, Tlen);
yystate(84, [45 | Ics], Line, Tlen, _, _) ->
    yystate(139, Ics, Line, Tlen + 1, 11, Tlen);
yystate(84, [43 | Ics], Line, Tlen, _, _) ->
    yystate(139, Ics, Line, Tlen + 1, 11, Tlen);
yystate(84, Ics, Line, Tlen, _, _) ->
    {11, Tlen, Ics, Line, 84};
yystate(83, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(83, Ics, Line, Tlen + 1, Action, Alen);
yystate(83, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(83, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(83, [9 | Ics], Line, Tlen, Action, Alen) ->
    yystate(83, Ics, Line, Tlen + 1, Action, Alen);
yystate(83, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 83};
yystate(82, [101 | Ics], Line, Tlen, _, _) ->
    yystate(128, Ics, Line, Tlen + 1, 20, Tlen);
yystate(82, [95 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 20, Tlen);
yystate(82, [69 | Ics], Line, Tlen, _, _) ->
    yystate(128, Ics, Line, Tlen + 1, 20, Tlen);
yystate(82, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(82, Ics, Line, Tlen + 1, 20, Tlen);
yystate(82, Ics, Line, Tlen, _, _) ->
    {20, Tlen, Ics, Line, 82};
yystate(81, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [50 | Ics], Line, Tlen, _, _) ->
    yystate(145, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [48 | Ics], Line, Tlen, _, _) ->
    yystate(106, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [49 | Ics], Line, Tlen, _, _) ->
    yystate(106, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [C | Ics], Line, Tlen, _, _) when C >= 51, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(81, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 81};
yystate(80, [101 | Ics], Line, Tlen, _, _) ->
    yystate(136, Ics, Line, Tlen + 1, 21, Tlen);
yystate(80, [95 | Ics], Line, Tlen, _, _) ->
    yystate(138, Ics, Line, Tlen + 1, 21, Tlen);
yystate(80, [69 | Ics], Line, Tlen, _, _) ->
    yystate(136, Ics, Line, Tlen + 1, 21, Tlen);
yystate(80, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 21, Tlen);
yystate(80, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(80, Ics, Line, Tlen + 1, 21, Tlen);
yystate(80, Ics, Line, Tlen, _, _) ->
    {21, Tlen, Ics, Line, 80};
yystate(79, [97 | Ics], Line, Tlen, _, _) ->
    yystate(19, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, [C | Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(79, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 79};
yystate(78, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [51 | Ics], Line, Tlen, _, _) ->
    yystate(14, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [49 | Ics], Line, Tlen, _, _) ->
    yystate(125, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [50 | Ics], Line, Tlen, _, _) ->
    yystate(125, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [48 | Ics], Line, Tlen, _, _) ->
    yystate(61, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [C | Ics], Line, Tlen, _, _) when C >= 52, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(78, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 78};
yystate(77, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(77, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(77, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(77, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(77, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(77, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 77};
yystate(76, [54 | Ics], Line, Tlen, Action, Alen) ->
    yystate(140, Ics, Line, Tlen + 1, Action, Alen);
yystate(76, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 53 ->
    yystate(6, Ics, Line, Tlen + 1, Action, Alen);
yystate(76, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 76};
yystate(75, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(75, [45 | Ics], Line, Tlen, _, _) ->
    yystate(68, Ics, Line, Tlen + 1, 29, Tlen);
yystate(75, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(75, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(75, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(75, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 75};
yystate(74, Ics, Line, Tlen, _, _) ->
    {27, Tlen, Ics, Line};
yystate(73, Ics, Line, Tlen, _, _) ->
    {1, Tlen, Ics, Line};
yystate(72, [95 | Ics], Line, Tlen, _, _) ->
    yystate(12, Ics, Line, Tlen + 1, 20, Tlen);
yystate(72, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(72, Ics, Line, Tlen + 1, 20, Tlen);
yystate(72, Ics, Line, Tlen, _, _) ->
    {20, Tlen, Ics, Line, 72};
yystate(71, [58 | Ics], Line, Tlen, Action, Alen) ->
    yystate(11, Ics, Line, Tlen + 1, Action, Alen);
yystate(71, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 71};
yystate(70, [95 | Ics], Line, Tlen, _, _) ->
    yystate(25, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [56 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [57 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 55 ->
    yystate(70, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 24, Tlen);
yystate(70, Ics, Line, Tlen, _, _) ->
    {24, Tlen, Ics, Line, 70};
yystate(69, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(69, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(69, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(5, Ics, Line, Tlen + 1, 29, Tlen);
yystate(69, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(69, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(69, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 69};
yystate(68, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [49 | Ics], Line, Tlen, _, _) ->
    yystate(132, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [48 | Ics], Line, Tlen, _, _) ->
    yystate(13, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [C | Ics], Line, Tlen, _, _) when C >= 50, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(68, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 68};
yystate(67, [39 | Ics], Line, Tlen, _, _) ->
    yystate(7, Ics, Line, Tlen + 1, 35, Tlen);
yystate(67, Ics, Line, Tlen, _, _) ->
    {35, Tlen, Ics, Line, 67};
yystate(66, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 15, Tlen);
yystate(66, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 15, Tlen);
yystate(66, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 15, Tlen);
yystate(66, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 15, Tlen);
yystate(66, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 15, Tlen);
yystate(66, Ics, Line, Tlen, _, _) ->
    {15, Tlen, Ics, Line, 66};
yystate(65, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 53 ->
    yystate(1, Ics, Line, Tlen + 1, Action, Alen);
yystate(65, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 65};
yystate(64, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, [48 | Ics], Line, Tlen, _, _) ->
    yystate(120, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, [C | Ics], Line, Tlen, _, _) when C >= 49, C =< 57 ->
    yystate(122, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(64, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 64};
yystate(63, Ics, Line, Tlen, _, _) ->
    {34, Tlen, Ics, Line};
yystate(62, [58 | Ics], Line, Tlen, Action, Alen) ->
    yystate(126, Ics, Line, Tlen + 1, Action, Alen);
yystate(62, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 62};
yystate(61, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, [48 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, [C | Ics], Line, Tlen, _, _) when C >= 49, C =< 57 ->
    yystate(17, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(61, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 61};
yystate(60, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 14, Tlen);
yystate(60, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 14, Tlen);
yystate(60, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 14, Tlen);
yystate(60, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 14, Tlen);
yystate(60, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 14, Tlen);
yystate(60, Ics, Line, Tlen, _, _) ->
    {14, Tlen, Ics, Line, 60};
yystate(59, [110 | Ics], Line, Tlen, _, _) ->
    yystate(115, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, [C | Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(59, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 59};
yystate(58, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [48 | Ics], Line, Tlen, _, _) ->
    yystate(120, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [45 | Ics], Line, Tlen, _, _) ->
    yystate(64, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [43 | Ics], Line, Tlen, _, _) ->
    yystate(4, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [C | Ics], Line, Tlen, _, _) when C >= 49, C =< 57 ->
    yystate(122, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(58, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 58};
yystate(57, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(163, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(57, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 57};
yystate(56, [34 | Ics], Line, Tlen, _, _) ->
    yystate(3, Ics, Line, Tlen + 1, 32, Tlen);
yystate(56, Ics, Line, Tlen, _, _) ->
    {32, Tlen, Ics, Line, 56};
yystate(55, [95 | Ics], Line, Tlen, _, _) ->
    yystate(119, Ics, Line, Tlen + 1, 20, Tlen);
yystate(55, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(55, Ics, Line, Tlen + 1, 20, Tlen);
yystate(55, Ics, Line, Tlen, _, _) ->
    {20, Tlen, Ics, Line, 55};
yystate(54, Ics, Line, Tlen, _, _) ->
    {9, Tlen, Ics, Line};
yystate(53, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(10, Ics, Line, Tlen + 1, Action, Alen);
yystate(53, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 53};
yystate(52, Ics, Line, Tlen, _, _) ->
    {37, Tlen, Ics, Line};
yystate(51, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(8, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(51, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 51};
yystate(50, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(50, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 50};
yystate(49, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(151, Ics, Line, Tlen + 1, Action, Alen);
yystate(49, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(151, Ics, Line, Tlen + 1, Action, Alen);
yystate(49, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(151, Ics, Line, Tlen + 1, Action, Alen);
yystate(49, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 49};
yystate(48, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(24, Ics, Line, Tlen + 1, Action, Alen);
yystate(48, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 48};
yystate(47, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(155, Ics, Line, Tlen + 1, Action, Alen);
yystate(47, [C | Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(72, Ics, Line, Tlen + 1, Action, Alen);
yystate(47, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 47};
yystate(46, Ics, Line, Tlen, _, _) ->
    {30, Tlen, Ics, Line};
yystate(45, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(93, Ics, Line, Tlen + 1, Action, Alen);
yystate(45, [105 | Ics], Line, Tlen, Action, Alen) ->
    yystate(53, Ics, Line, Tlen + 1, Action, Alen);
yystate(45, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(20, Ics, Line, Tlen + 1, Action, Alen);
yystate(45, [C | Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(80, Ics, Line, Tlen + 1, Action, Alen);
yystate(45, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 45};
yystate(44, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, [58 | Ics], Line, Tlen, _, _) ->
    yystate(99, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(15, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(44, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 44};
yystate(43, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(16, Ics, Line, Tlen + 1, Action, Alen);
yystate(43, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 43};
yystate(42, [50 | Ics], Line, Tlen, Action, Alen) ->
    yystate(21, Ics, Line, Tlen + 1, Action, Alen);
yystate(42, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(149, Ics, Line, Tlen + 1, Action, Alen);
yystate(42, [49 | Ics], Line, Tlen, Action, Alen) ->
    yystate(149, Ics, Line, Tlen + 1, Action, Alen);
yystate(42, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 42};
yystate(41, Ics, Line, Tlen, _, _) ->
    {5, Tlen, Ics, Line};
yystate(40, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 26, Tlen);
yystate(40, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 26, Tlen);
yystate(40, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 26, Tlen);
yystate(40, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 26, Tlen);
yystate(40, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 26, Tlen);
yystate(40, Ics, Line, Tlen, _, _) ->
    {26, Tlen, Ics, Line, 40};
yystate(39, [39 | Ics], Line, Tlen, Action, Alen) ->
    yystate(103, Ics, Line, Tlen + 1, Action, Alen);
yystate(39, [C | Ics], Line, Tlen, Action, Alen) when C >= 32, C =< 38 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(39, [C | Ics], Line, Tlen, Action, Alen) when C >= 40, C =< 126 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(39, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(158, Ics, Line, Tlen + 1, Action, Alen);
yystate(39, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 39};
yystate(38, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(38, Ics, Line, Tlen + 1, 13, Tlen);
yystate(38, Ics, Line, Tlen, _, _) ->
    {13, Tlen, Ics, Line, 38};
yystate(37, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(101, Ics, Line, Tlen + 1, Action, Alen);
yystate(37, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(101, Ics, Line, Tlen + 1, Action, Alen);
yystate(37, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(101, Ics, Line, Tlen + 1, Action, Alen);
yystate(37, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 37};
yystate(36, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(161, Ics, Line, Tlen + 1, Action, Alen);
yystate(36, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(161, Ics, Line, Tlen + 1, Action, Alen);
yystate(36, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(161, Ics, Line, Tlen + 1, Action, Alen);
yystate(36, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 36};
yystate(35, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(91, Ics, Line, Tlen + 1, Action, Alen);
yystate(35, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 35};
yystate(34, Ics, Line, Tlen, _, _) ->
    {3, Tlen, Ics, Line};
yystate(33, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(97, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(87, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [33 | Ics], Line, Tlen, Action, Alen) ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [C | Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [C | Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 126 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(156, Ics, Line, Tlen + 1, Action, Alen);
yystate(33, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 33};
yystate(32, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(32, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 32};
yystate(31, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 17, Tlen);
yystate(31, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 17, Tlen);
yystate(31, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 17, Tlen);
yystate(31, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 17, Tlen);
yystate(31, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 17, Tlen);
yystate(31, Ics, Line, Tlen, _, _) ->
    {17, Tlen, Ics, Line, 31};
yystate(30, [C | Ics], Line, Tlen, _, _) when C >= 0, C =< 9 ->
    yystate(30, Ics, Line, Tlen + 1, 39, Tlen);
yystate(30, [C | Ics], Line, Tlen, _, _) when C >= 11 ->
    yystate(30, Ics, Line, Tlen + 1, 39, Tlen);
yystate(30, Ics, Line, Tlen, _, _) ->
    {39, Tlen, Ics, Line, 30};
yystate(29, Ics, Line, Tlen, _, _) ->
    {2, Tlen, Ics, Line};
yystate(28, [97 | Ics], Line, Tlen, _, _) ->
    yystate(88, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, [C | Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(28, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 28};
yystate(27, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(147, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(56, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [33 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(27, [C | Ics], Line, Tlen, Action, Alen) when C >= 35, C =< 91 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [C | Ics], Line, Tlen, Action, Alen) when C >= 93, C =< 126 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, [C | Ics], Line, Tlen, Action, Alen) when C >= 128 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(27, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 27};
yystate(26, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(37, Ics, Line, Tlen + 1, Action, Alen);
yystate(26, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(37, Ics, Line, Tlen + 1, Action, Alen);
yystate(26, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(37, Ics, Line, Tlen + 1, Action, Alen);
yystate(26, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 26};
yystate(25, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [56 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [57 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 55 ->
    yystate(70, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(25, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 25};
yystate(24, Ics, Line, Tlen, _, _) ->
    {10, Tlen, Ics, Line};
yystate(23, [117 | Ics], Line, Tlen, Action, Alen) ->
    yystate(165, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [116 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [114 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [110 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [102 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [98 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [92 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [85 | Ics], Line, Tlen, Action, Alen) ->
    yystate(90, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [34 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [32 | Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [13 | Ics], Line, Tlen, Action, Alen) ->
    yystate(32, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, [10 | Ics], Line, Tlen, Action, Alen) ->
    yystate(92, Ics, Line + 1, Tlen + 1, Action, Alen);
yystate(23, [9 | Ics], Line, Tlen, Action, Alen) ->
    yystate(98, Ics, Line, Tlen + 1, Action, Alen);
yystate(23, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 23};
yystate(22, Ics, Line, Tlen, _, _) ->
    {4, Tlen, Ics, Line};
yystate(21, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 51 ->
    yystate(85, Ics, Line, Tlen + 1, Action, Alen);
yystate(21, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 21};
yystate(20, [101 | Ics], Line, Tlen, _, _) ->
    yystate(136, Ics, Line, Tlen + 1, 21, Tlen);
yystate(20, [69 | Ics], Line, Tlen, _, _) ->
    yystate(136, Ics, Line, Tlen + 1, 21, Tlen);
yystate(20, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 21, Tlen);
yystate(20, Ics, Line, Tlen, _, _) ->
    {21, Tlen, Ics, Line, 20};
yystate(19, [110 | Ics], Line, Tlen, _, _) ->
    yystate(40, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 109 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, [C | Ics], Line, Tlen, _, _) when C >= 111, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(19, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 19};
yystate(18, Ics, Line, Tlen, _, _) ->
    {8, Tlen, Ics, Line};
yystate(17, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [84 | Ics], Line, Tlen, _, _) ->
    yystate(81, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [32 | Ics], Line, Tlen, _, _) ->
    yystate(42, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 83 ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [C | Ics], Line, Tlen, _, _) when C >= 85, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 12, Tlen);
yystate(17, Ics, Line, Tlen, _, _) ->
    {12, Tlen, Ics, Line, 17};
yystate(16, [58 | Ics], Line, Tlen, Action, Alen) ->
    yystate(76, Ics, Line, Tlen + 1, Action, Alen);
yystate(16, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 16};
yystate(15, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(15, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(15, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(75, Ics, Line, Tlen + 1, 29, Tlen);
yystate(15, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(15, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(15, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 15};
yystate(14, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [48 | Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [49 | Ics], Line, Tlen, _, _) ->
    yystate(17, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [C | Ics], Line, Tlen, _, _) when C >= 50, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(14, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 14};
yystate(13, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, [48 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, [C | Ics], Line, Tlen, _, _) when C >= 49, C =< 57 ->
    yystate(142, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(13, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 13};
yystate(12, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(72, Ics, Line, Tlen + 1, Action, Alen);
yystate(12, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 12};
yystate(11, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 53 ->
    yystate(48, Ics, Line, Tlen + 1, Action, Alen);
yystate(11, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 11};
yystate(10, [102 | Ics], Line, Tlen, Action, Alen) ->
    yystate(74, Ics, Line, Tlen + 1, Action, Alen);
yystate(10, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 10};
yystate(9, [93 | Ics], Line, Tlen, _, _) ->
    yystate(73, Ics, Line, Tlen + 1, 38, Tlen);
yystate(9, [91 | Ics], Line, Tlen, _, _) ->
    yystate(137, Ics, Line, Tlen + 1, 38, Tlen);
yystate(9, [32 | Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen + 1, 38, Tlen);
yystate(9, [9 | Ics], Line, Tlen, _, _) ->
    yystate(9, Ics, Line, Tlen + 1, 38, Tlen);
yystate(9, Ics, Line, Tlen, _, _) ->
    {38, Tlen, Ics, Line, 9};
yystate(8, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [45 | Ics], Line, Tlen, _, _) ->
    yystate(68, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(5, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(8, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 8};
yystate(7, [39 | Ics], Line, Tlen, _, _) ->
    yystate(52, Ics, Line, Tlen + 1, 36, Tlen);
yystate(7, Ics, Line, Tlen, _, _) ->
    {36, Tlen, Ics, Line, 7};
yystate(6, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(166, Ics, Line, Tlen + 1, Action, Alen);
yystate(6, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 6};
yystate(5, [101 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [95 | Ics], Line, Tlen, _, _) ->
    yystate(69, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [69 | Ics], Line, Tlen, _, _) ->
    yystate(58, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [46 | Ics], Line, Tlen, _, _) ->
    yystate(146, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(5, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 68 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [C | Ics], Line, Tlen, _, _) when C >= 70, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [C | Ics], Line, Tlen, _, _) when C >= 97, C =< 100 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, [C | Ics], Line, Tlen, _, _) when C >= 102, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 19, Tlen);
yystate(5, Ics, Line, Tlen, _, _) ->
    {19, Tlen, Ics, Line, 5};
yystate(4, [48 | Ics], Line, Tlen, Action, Alen) ->
    yystate(155, Ics, Line, Tlen + 1, Action, Alen);
yystate(4, [C | Ics], Line, Tlen, Action, Alen) when C >= 49, C =< 57 ->
    yystate(55, Ics, Line, Tlen + 1, Action, Alen);
yystate(4, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 4};
yystate(3, [34 | Ics], Line, Tlen, _, _) ->
    yystate(63, Ics, Line, Tlen + 1, 33, Tlen);
yystate(3, Ics, Line, Tlen, _, _) ->
    {33, Tlen, Ics, Line, 3};
yystate(2, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(2, [C | Ics], Line, Tlen, Action, Alen) when C >= 65, C =< 70 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(2, [C | Ics], Line, Tlen, Action, Alen) when C >= 97, C =< 102 ->
    yystate(92, Ics, Line, Tlen + 1, Action, Alen);
yystate(2, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 2};
yystate(1, [C | Ics], Line, Tlen, Action, Alen) when C >= 48, C =< 57 ->
    yystate(62, Ics, Line, Tlen + 1, Action, Alen);
yystate(1, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, 1};
yystate(0, [97 | Ics], Line, Tlen, _, _) ->
    yystate(59, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, [95 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, [45 | Ics], Line, Tlen, _, _) ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, [C | Ics], Line, Tlen, _, _) when C >= 48, C =< 57 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, [C | Ics], Line, Tlen, _, _) when C >= 65, C =< 90 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, [C | Ics], Line, Tlen, _, _) when C >= 98, C =< 122 ->
    yystate(77, Ics, Line, Tlen + 1, 29, Tlen);
yystate(0, Ics, Line, Tlen, _, _) ->
    {29, Tlen, Ics, Line, 0};
yystate(S, Ics, Line, Tlen, Action, Alen) ->
    {Action, Alen, Tlen, Ics, Line, S}.

%% yyaction(Action, TokenLength, TokenChars, TokenLine) ->
%% {token,Token} | {end_token, Token} | skip_token | {error,String}.
%% Generated action function.

yyaction(0, _, _, TokenLine) ->
    yyaction_0(TokenLine);
yyaction(1, _, _, TokenLine) ->
    yyaction_1(TokenLine);
yyaction(2, _, _, TokenLine) ->
    yyaction_2(TokenLine);
yyaction(3, _, _, TokenLine) ->
    yyaction_3(TokenLine);
yyaction(4, _, _, TokenLine) ->
    yyaction_4(TokenLine);
yyaction(5, _, _, TokenLine) ->
    yyaction_5(TokenLine);
yyaction(6, _, _, TokenLine) ->
    yyaction_6(TokenLine);
yyaction(7, _, _, TokenLine) ->
    yyaction_7(TokenLine);
yyaction(8, _, _, TokenLine) ->
    yyaction_8(TokenLine);
yyaction(9, _, _, TokenLine) ->
    yyaction_9(TokenLine);
yyaction(10, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_10(TokenChars, TokenLine);
yyaction(11, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_11(TokenChars, TokenLine);
yyaction(12, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_12(TokenChars, TokenLine);
yyaction(13, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_13(TokenChars, TokenLine);
yyaction(14, _, _, TokenLine) ->
    yyaction_14(TokenLine);
yyaction(15, _, _, TokenLine) ->
    yyaction_15(TokenLine);
yyaction(16, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_16(TokenChars, TokenLine);
yyaction(17, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_17(TokenChars, TokenLine);
yyaction(18, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_18(TokenChars, TokenLine);
yyaction(19, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_19(TokenChars, TokenLine);
yyaction(20, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_20(TokenChars, TokenLine);
yyaction(21, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_21(TokenChars, TokenLine);
yyaction(22, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_22(TokenChars, TokenLine);
yyaction(23, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_23(TokenChars, TokenLine);
yyaction(24, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_24(TokenChars, TokenLine);
yyaction(25, _, _, TokenLine) ->
    yyaction_25(TokenLine);
yyaction(26, _, _, TokenLine) ->
    yyaction_26(TokenLine);
yyaction(27, _, _, TokenLine) ->
    yyaction_27(TokenLine);
yyaction(28, _, _, TokenLine) ->
    yyaction_28(TokenLine);
yyaction(29, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_29(TokenChars, TokenLine);
yyaction(30, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_30(TokenChars, TokenLine);
yyaction(31, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_31(TokenChars, TokenLine);
yyaction(32, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_32(TokenChars, TokenLine);
yyaction(33, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_33(TokenChars, TokenLine);
yyaction(34, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_34(TokenChars, TokenLine);
yyaction(35, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_35(TokenChars, TokenLine);
yyaction(36, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_36(TokenChars, TokenLine);
yyaction(37, TokenLen, YYtcs, TokenLine) ->
    TokenChars = yypre(YYtcs, TokenLen),
    yyaction_37(TokenChars, TokenLine);
yyaction(38, _, _, _) ->
    yyaction_38();
yyaction(39, _, _, _) ->
    yyaction_39();
yyaction(_, _, _, _) ->
    error.

-compile({inline, yyaction_0/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 57).
yyaction_0(TokenLine) ->
    {token, {space, TokenLine}, "["}.

-compile({inline, yyaction_1/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 58).
yyaction_1(TokenLine) ->
    {token, {space, TokenLine}, "]"}.

-compile({inline, yyaction_2/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 59).
yyaction_2(TokenLine) ->
    {token, {'[', TokenLine}}.

-compile({inline, yyaction_3/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 60).
yyaction_3(TokenLine) ->
    {token, {']', TokenLine}}.

-compile({inline, yyaction_4/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 61).
yyaction_4(TokenLine) ->
    {token, {'{', TokenLine}}.

-compile({inline, yyaction_5/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 62).
yyaction_5(TokenLine) ->
    {token, {'}', TokenLine}}.

-compile({inline, yyaction_6/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 63).
yyaction_6(TokenLine) ->
    {token, {'.', TokenLine}}.

-compile({inline, yyaction_7/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 64).
yyaction_7(TokenLine) ->
    {token, {'=', TokenLine}}.

-compile({inline, yyaction_8/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 65).
yyaction_8(TokenLine) ->
    {token, {',', TokenLine}}.

-compile({inline, yyaction_9/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 66).
yyaction_9(TokenLine) ->
    {token, {nl, TokenLine}}.

-compile({inline, yyaction_10/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 68).
yyaction_10(TokenChars, TokenLine) ->
    {token, {datetime_tz, TokenLine, datetime_tz(TokenChars)}}.

-compile({inline, yyaction_11/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 69).
yyaction_11(TokenChars, TokenLine) ->
    {token, {local_datetime, TokenLine, local_datetime(TokenChars)}}.

-compile({inline, yyaction_12/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 71).
yyaction_12(TokenChars, TokenLine) ->
    {token, {maybe_key, TokenLine, {local_date, TokenChars, local_date(TokenChars)}}}.

-compile({inline, yyaction_13/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 72).
yyaction_13(TokenChars, TokenLine) ->
    {token, {local_time, TokenLine, local_time(TokenChars)}}.

-compile({inline, yyaction_14/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 75).
yyaction_14(TokenLine) ->
    {token, {bool, TokenLine, true}}.

-compile({inline, yyaction_15/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 76).
yyaction_15(TokenLine) ->
    {token, {bool, TokenLine, false}}.

-compile({inline, yyaction_16/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 77).
yyaction_16(TokenChars, TokenLine) ->
    {token, {maybe_key, TokenLine, {float, TokenChars, nan}}}.

-compile({inline, yyaction_17/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 78).
yyaction_17(TokenChars, TokenLine) ->
    {token, {maybe_key, TokenLine, {float, TokenChars, infinity}}}.

-compile({inline, yyaction_18/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 80).
yyaction_18(TokenChars, TokenLine) ->
    {token, {maybe_key, TokenLine, {float, TokenChars, to_float(TokenChars)}}}.

-compile({inline, yyaction_19/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 81).
yyaction_19(TokenChars, TokenLine) ->
    {token, {maybe_key, TokenLine, {integer, TokenChars, to_integer(TokenChars)}}}.

-compile({inline, yyaction_20/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 82).
yyaction_20(TokenChars, TokenLine) ->
    {token, {float, TokenLine, to_float(TokenChars)}}.

-compile({inline, yyaction_21/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 83).
yyaction_21(TokenChars, TokenLine) ->
    {token, {integer, TokenLine, to_integer(TokenChars)}}.

-compile({inline, yyaction_22/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 84).
yyaction_22(TokenChars, TokenLine) ->
    {token, {integer, TokenLine, to_integer(TokenChars)}}.

-compile({inline, yyaction_23/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 85).
yyaction_23(TokenChars, TokenLine) ->
    {token, {integer, TokenLine, to_integer(TokenChars)}}.

-compile({inline, yyaction_24/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 86).
yyaction_24(TokenChars, TokenLine) ->
    {token, {integer, TokenLine, to_integer(TokenChars)}}.

-compile({inline, yyaction_25/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 89).
yyaction_25(TokenLine) ->
    {token, {float, TokenLine, nan}}.

-compile({inline, yyaction_26/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 90).
yyaction_26(TokenLine) ->
    {token, {float, TokenLine, nan}}.

-compile({inline, yyaction_27/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 91).
yyaction_27(TokenLine) ->
    {token, {float, TokenLine, infinity}}.

-compile({inline, yyaction_28/1}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 92).
yyaction_28(TokenLine) ->
    {token, {float, TokenLine, negative_infinity}}.

-compile({inline, yyaction_29/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 93).
yyaction_29(TokenChars, TokenLine) ->
    {token, {bare_key, TokenLine, TokenChars}}.

-compile({inline, yyaction_30/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 95).
yyaction_30(TokenChars, TokenLine) ->
    {token, {basic_string, TokenLine, basic_string(TokenChars)}}.

-compile({inline, yyaction_31/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 96).
yyaction_31(TokenChars, TokenLine) ->
    {token, {literal_string, TokenLine, literal_string(TokenChars)}}.

-compile({inline, yyaction_32/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 97).
yyaction_32(TokenChars, TokenLine) ->
    {token, {basic_string_ml, TokenLine, basic_string_ml(TokenChars)}}.

-compile({inline, yyaction_33/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 98).
yyaction_33(TokenChars, TokenLine) ->
    {token, {basic_string_ml, TokenLine, basic_string_ml(TokenChars)}}.

-compile({inline, yyaction_34/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 99).
yyaction_34(TokenChars, TokenLine) ->
    {token, {basic_string_ml, TokenLine, basic_string_ml(TokenChars)}}.

-compile({inline, yyaction_35/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 100).
yyaction_35(TokenChars, TokenLine) ->
    {token, {literal_string_ml, TokenLine, literal_string_ml(TokenChars)}}.

-compile({inline, yyaction_36/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 101).
yyaction_36(TokenChars, TokenLine) ->
    {token, {literal_string_ml, TokenLine, literal_string_ml(TokenChars)}}.

-compile({inline, yyaction_37/2}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 102).
yyaction_37(TokenChars, TokenLine) ->
    {token, {literal_string_ml, TokenLine, literal_string_ml(TokenChars)}}.

-compile({inline, yyaction_38/0}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 104).
yyaction_38() ->
    skip_token.

-compile({inline, yyaction_39/0}).
-file("/home/benedikt/git/tomerl/src/tomerl_lexer.xrl", 105).
yyaction_39() ->
    skip_token.

-file("/usr/lib64/erlang/lib/parsetools-2.3/include/leexinc.hrl", 313).
